<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>在瀏覽器之外的生活！</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>版本 %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>授權使用：%1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 是免費軟體，但其發展需要寶貴的時間。</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>請 &lt;a href=&apos;%1&apos;&gt;贊助&lt;/a&gt; 以支持持續發展 %2。</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>使用 %2 翻譯 %1 介面成為您的本國語言</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>威力本源 %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>開放原始碼軟體</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>圖示由 %1 所設計。 </translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>發布在 &lt;a href=&apos;%1&apos;&gt;GNU 通用公共授權條款&lt;/a&gt;之下</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>輸入您的使用授權詳細資料</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>電子郵件(&amp;E)：</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>授權碼(&amp;C)：</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>請取得 %1 授權</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>完整的版本允許您不被中斷地觀看影片。</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>透過購買完整版，您還可以支持我投入更多心力於打造 %1。</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>使用展示版</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>輸入授權</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>購買授權</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>下載</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>依 %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>您有 %n 個新影片</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>全部影片</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>尚未觀看的影片</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>最近更新的</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>最近加入的</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>最近看過的</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>最多觀賞次數</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>排序根據</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>標記全部為看過的</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>顯示更新</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>您暫時沒有任何訂閱。使用星星符號訂閱頻道。</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>全部影片</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>尚未觀看的影片</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>標記為已觀看</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>取消訂閱</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>目前沒有更新的訂閱。</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>就是現在</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>%n 小時前</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>%n 天前</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>%n 個月前</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>瀏覽次數：%1 次</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>%n 週前</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation><numerusform>%n 年前</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/秒</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/秒</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/秒</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>剩餘 %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 下載在 %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>下載完成</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n 次下載</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>變更位置...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>選擇下載位置</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>下載位置已變更。</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>目前的下載仍然會進入先前的位置。</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>下載至：%1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>可執行檔可能已被病毒竄改。</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 將不會執行。嘗試再次安裝。</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>離開</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>重新安裝</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>播放/暫停</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>在目前的曲目之後，停止播放</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>下一首曲目</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>上一首曲目</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>增加音量</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>減少音量</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>快轉</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>倒轉</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>用關鍵字尋找影片和頻道</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>按類別瀏覽影片</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>訂閱</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>頻道訂閱</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>您可以盡情享受</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>視窗(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>最小化(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>停止(&amp;S)</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>停止播放並回到搜尋檢視中</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>上一個(&amp;R)</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>回到上一個影片</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>下一個(&amp;K)</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>跳至下一個影片</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>播放(&amp;P)</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>恢復播放</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>全螢幕(&amp;F)</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>切換至全螢幕</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>精簡模式(&amp;C)</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>隱藏播放清單和工具列</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>開啟 &amp;YouTube 頁面</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>前往 YouTube 影片頁面並且暫停播放</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>複製 YouTube 的連結(&amp;L)</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>複製目前 YouTube 影片的連結到剪貼簿</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>複製影片串流網址(&amp;U)</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>複製目前影片串流網址到剪貼簿</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>找到其他影片部分(&amp;P)</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>希望能以正確的順序找到其他影片部分</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>從播放清單中移除所選的影片</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>向上移動(&amp;U)</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>向上移動在播放清單中所選的影片</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>向下移動(&amp;D)</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>向下移動在播放清單中所選的影片</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>清除最近的搜尋(&amp;C)</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>清除搜尋歷史記錄。不能撤消。</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>結束(&amp;Q)</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>再見</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>網站(&amp;W)</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>在網絡上的 %1</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>贊助(&amp;D)</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>請支持持續發展 %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>有關 %1 訊息</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>手動啟動播放(&amp;M)</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>手動啟動播放影片</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>下載(&amp;D)</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>顯示影片下載細節</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>下載(&amp;D)</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>下載目前的影片</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>拍攝快照(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>訂閱頻道(&amp;S)</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>分享目前的影片使用 %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>電子郵件(&amp;E)</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>電子郵件</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>浮在上面(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>在這個影片播完之後停止(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>回報問題(&amp;R)...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>精確搜尋(&amp;R)...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>更多...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>相關影片(&amp;R)</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>觀看和目前相關的影片</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>在瀏覽器中開啟(&amp;B)...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>限制模式</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>隱藏可能包含不適當內容的影片</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>切換選單列(&amp;M)</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>選單</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>喜歡 %1 ？為它評分！(&amp;L)</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>購買 %1</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>應用(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>播放(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>播放清單(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>影片(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>分享(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>檢視(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>幫助(&amp;H)</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>按 %1 提高音量，%2 降低音量</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>選擇您的內容定位</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>開啟 %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>您想要下載正在進行中結束 %1？</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>如果現在關閉 %1，下載將被取消。</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>關閉並取消下載</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>等待下載完成</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>錯誤：%1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>暫停(&amp;P)</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>暫停播放</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>正在載入... (&amp;L)</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>離開全螢幕(&amp;F)</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>剩餘時間：%1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>音量達到 %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>音量處於靜音狀態</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>音量處於非靜音狀態</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>影片最大解析度設定為 %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>您的隱私現在是安全的</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>下載完成</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>您還是可以透過按下 ALT 鍵存取選單列</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>您現在可以貼上 YouTube 的連結到另一個應用程式中</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>現在，您可以貼上影片串流網址到其他應用中</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>這個連結將只在有限的時間內有效。</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>正在下載 %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>/</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>部分</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>集</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>從 %1 發送</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>取消訂閱 %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>訂閱 %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>切換至 %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>從 %1 取消訂閱</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>已訂閱 %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation>倒帶 %1 秒</translation>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation>快轉 %1 秒</translation>
    </message>
    <message>
        <source>channel</source>
        <translation>頻道</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>有新版本的 %1 可用</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 現在可用。您有 %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>您想現在就下載嗎？</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>跳過此版本</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>稍候提醒我</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>安裝更新</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>挑選影片</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 / %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>準備</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>失敗</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>停止下載</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>顯示在 %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>開啟檔案所在資料夾</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>重新啟動下載</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>顯示再多 %1個影片</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>沒有影片</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>沒有更多的影片</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>排序根據</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>相關性</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>觀看次數</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>評價</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>任何時間</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7天</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30天</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>長短</translation>
    </message>
    <message>
        <source>All</source>
        <translation>所有</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>短</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>長</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>不到4分鐘</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>介於4和20分鐘</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>超過20分鐘</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>品質</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>今年</translation>
    </message>
    <message>
        <source>HD</source>
        <translation>HD</translation>
    </message>
    <message>
        <source>4K</source>
        <translation>4K</translation>
    </message>
    <message>
        <source>HDR</source>
        <translation>HDR</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>歡迎使用 &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>以開始觀看影片。</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>一個關鍵字</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>輸入</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>最近的關鍵字</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>最近的頻道</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>取得完整版</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation>需要遙控 %1？試試看 %2！</translation>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation>我會不斷改善 %1，讓它變得更好。請支持我的努力！</translation>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation>準備好安裝更新。結束並安裝更新。</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>後退(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>前進(&amp;F)</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>向前到 %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>退後到 %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>精確搜尋</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>您的意思是：%1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>變更位置...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>快照已儲存到 %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>快照位置已改變。</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>最熱門</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation>發燒影片</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>News</source>
        <translation>新聞</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>電影</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>遊戲</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>正在下載更新...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>正在下載 %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation>正在檢查更新……</translation>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation>版本 %1 已可使用……</translation>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation>正在下載 %1……</translation>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation>重新啟動以更新</translation>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation>版本 %1 下載失敗</translation>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>下載更新</translation>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>正在下載更新...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation>重試更新下載</translation>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation>您已有最新版本。</translation>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation>版本 %1 已可使用。</translation>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation>更新已下載且已準備好安裝。</translation>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>無法為 %1 取得影片串流</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>阿爾及利亞</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>阿根廷</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>澳大利亞</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>比利時</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>巴西</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>加拿大</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>智利</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>哥倫比亞</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>捷克共和國</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>埃及</translation>
    </message>
    <message>
        <source>France</source>
        <translation>法國</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>德國</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>加納</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>希臘</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>香港</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>匈牙利</translation>
    </message>
    <message>
        <source>India</source>
        <translation>印度</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>印尼</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>愛爾蘭</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>以色列</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>意大利</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>日本</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>約旦</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>肯亞</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>馬來西亞</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>墨西哥</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>摩洛哥</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>荷蘭</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>紐西蘭</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>奈及利亞</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>秘魯</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>菲律賓</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>波蘭</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>俄羅斯</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>沙烏地阿拉伯</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>新加坡</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>南非</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>南韓</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>西班牙</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>瑞典</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>台灣</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>突尼西亞</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>土耳其</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>烏干達</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>阿拉伯聯合大公國</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>英國</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>葉門</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>全世界</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>無法為 %1 取得影片串流</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation>目前沒有可用的更新。</translation>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation>您已有最新版本</translation>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation>正在下載 %1 %2……</translation>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>一個新版的 %1 可用！</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 現在可用。您有 %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>您想現在就下載嗎？</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>稍後提醒我</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>下載更新</translation>
    </message>
</context>
</TS>